==> java-1.2.3.tar.gz: java-1.2.3/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/client/TestHttp_LocalAxisRaspServer.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and 
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 *
 * Contributor(s):
 *   Tommy Dejbjerg Pedersen, Lenio
 *   Hans Guldager Knudsen, Lenio
 *   Patrik Johansson, Accenture
 *   Dennis Sgaard, Accenture
 *   Martin Bentzen, Accenture
 *   Jesper Jensen, Avanade
 *   Ramzi Fadel, Avanade
 *   Christian Pedersen, Accenture
 *   Morten Hougesen, Accenture
 *   Mikkel Hippe Brun, ITST
 *   Finn Hartmann Jordal, ITST
 *   Christian Lanng, ITST
 *
 */

package dk.gov.oiosi.test.client;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;

/**
 * Test against local install server.
 */
public class TestHttp_LocalAxisRaspServer extends AbstractTestRaspStackInterop {

    static {
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_TEST_RASPCONFIGURATION);
    }

    /**
     * default host + url for local rasp tests.
     */
    private static String RASP_HOST = "http://localhost:8080/oiosirasp/services/";

    /* (non-Javadoc)
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getEndpointUrl(java.lang.String)
     */
    public String getEndpointUrl(String service) {
        return RASP_HOST + service;
    }

    /*
     * (non-Javadoc)
     * 
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getDefaultServerKeylabel()
     */
    protected String getDefaultServerKeylabel() {
        return "server";
    }

    public void localCleanup() throws Exception {
        Thread.sleep(5000);
    }

    /*
     * (non-Javadoc)
     * 
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getProxy()
     */
    protected int getProxy() {
        return 0;
    }

}

==> java-2.0.0.tar.gz: java-2.0.0/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/client/TestHttp_LocalAxisRaspServer.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.client;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;

/**
 * Test against local install server.
 */
public class TestHttp_LocalAxisRaspServer extends AbstractTestRaspStackInterop {

    static {
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    /**
     * default host + url for local rasp tests.
     */
    private static String RASP_HOST = "http://localhost:8080/oiosirasp/services/";

    /* (non-Javadoc)
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getEndpointUrl(java.lang.String)
     */
    public String getEndpointUrl(String service) {
        return RASP_HOST + service;
    }

    /*
     * (non-Javadoc)
     *
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getDefaultServerKeylabel()
     */
    protected String getDefaultServerKeylabel() {
        return "server";
    }

    public void localCleanup() throws Exception {
        Thread.sleep(5000);
    }

    /*
     * (non-Javadoc)
     *
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getProxy()
     */
    protected int getProxy() {
        return 0;
    }

}
